# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/execution/v1/deletion.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n qwak/execution/v1/deletion.proto\x12\x1fqwak.feature.store.execution.v1\"\x84\x01\n\x12\x46\x65\x61turesetDeletion\x12]\n\x19\x62\x61tch_featureset_deletion\x18\x01 \x01(\x0b\x32\x38.qwak.feature.store.execution.v1.BatchFeaturesetDeletionH\x00\x42\x0f\n\rdeletion_type\"\x19\n\x17\x42\x61tchFeaturesetDeletionB)\n%com.qwak.ai.features.execution.api.v1P\x01\x62\x06proto3')



_FEATURESETDELETION = DESCRIPTOR.message_types_by_name['FeaturesetDeletion']
_BATCHFEATURESETDELETION = DESCRIPTOR.message_types_by_name['BatchFeaturesetDeletion']
FeaturesetDeletion = _reflection.GeneratedProtocolMessageType('FeaturesetDeletion', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETDELETION,
  '__module__' : 'qwak.execution.v1.deletion_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.FeaturesetDeletion)
  })
_sym_db.RegisterMessage(FeaturesetDeletion)

BatchFeaturesetDeletion = _reflection.GeneratedProtocolMessageType('BatchFeaturesetDeletion', (_message.Message,), {
  'DESCRIPTOR' : _BATCHFEATURESETDELETION,
  '__module__' : 'qwak.execution.v1.deletion_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.BatchFeaturesetDeletion)
  })
_sym_db.RegisterMessage(BatchFeaturesetDeletion)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.features.execution.api.v1P\001'
  _FEATURESETDELETION._serialized_start=70
  _FEATURESETDELETION._serialized_end=202
  _BATCHFEATURESETDELETION._serialized_start=204
  _BATCHFEATURESETDELETION._serialized_end=229
# @@protoc_insertion_point(module_scope)
