# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/builds/internal_builds_orchestrator_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.builds import build_pb2 as qwak_dot_builds_dot_build__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6qwak/builds/internal_builds_orchestrator_service.proto\x12\x18qwak.builds.orchestrator\x1a\x17qwak/builds/build.proto\"\x8e\x01\n\x10\x42uildInitDetails\x12=\n\nbuild_spec\x18\x01 \x01(\x0b\x32).qwak.builds.orchestrator.RemoteBuildSpec\x12;\n\tinitiator\x18\x02 \x01(\x0b\x32(.qwak.builds.orchestrator.BuildInitiator\"c\n\x19InternalBuildModelRequest\x12\x46\n\x12\x62uild_init_details\x18\x01 \x01(\x0b\x32*.qwak.builds.orchestrator.BuildInitDetails\"\x1c\n\x1aInternalBuildModelResponse2\x9c\x01\n!InternalBuildsOrchestratorService\x12w\n\nBuildModel\x12\x33.qwak.builds.orchestrator.InternalBuildModelRequest\x1a\x34.qwak.builds.orchestrator.InternalBuildModelResponseB\'\n#com.qwak.ai.builds.orchestrator.apiP\x01\x62\x06proto3')



_BUILDINITDETAILS = DESCRIPTOR.message_types_by_name['BuildInitDetails']
_INTERNALBUILDMODELREQUEST = DESCRIPTOR.message_types_by_name['InternalBuildModelRequest']
_INTERNALBUILDMODELRESPONSE = DESCRIPTOR.message_types_by_name['InternalBuildModelResponse']
BuildInitDetails = _reflection.GeneratedProtocolMessageType('BuildInitDetails', (_message.Message,), {
  'DESCRIPTOR' : _BUILDINITDETAILS,
  '__module__' : 'qwak.builds.internal_builds_orchestrator_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.BuildInitDetails)
  })
_sym_db.RegisterMessage(BuildInitDetails)

InternalBuildModelRequest = _reflection.GeneratedProtocolMessageType('InternalBuildModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALBUILDMODELREQUEST,
  '__module__' : 'qwak.builds.internal_builds_orchestrator_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.InternalBuildModelRequest)
  })
_sym_db.RegisterMessage(InternalBuildModelRequest)

InternalBuildModelResponse = _reflection.GeneratedProtocolMessageType('InternalBuildModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALBUILDMODELRESPONSE,
  '__module__' : 'qwak.builds.internal_builds_orchestrator_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.InternalBuildModelResponse)
  })
_sym_db.RegisterMessage(InternalBuildModelResponse)

_INTERNALBUILDSORCHESTRATORSERVICE = DESCRIPTOR.services_by_name['InternalBuildsOrchestratorService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.qwak.ai.builds.orchestrator.apiP\001'
  _BUILDINITDETAILS._serialized_start=110
  _BUILDINITDETAILS._serialized_end=252
  _INTERNALBUILDMODELREQUEST._serialized_start=254
  _INTERNALBUILDMODELREQUEST._serialized_end=353
  _INTERNALBUILDMODELRESPONSE._serialized_start=355
  _INTERNALBUILDMODELRESPONSE._serialized_end=383
  _INTERNALBUILDSORCHESTRATORSERVICE._serialized_start=386
  _INTERNALBUILDSORCHESTRATORSERVICE._serialized_end=542
# @@protoc_insertion_point(module_scope)
