# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.execution.v1.state import execution_state_service_pb2 as qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2


class FeatureStoreExecutionStateServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetFeaturesetStateById = channel.unary_unary(
                '/qwak.feature.store.execution.v1.state.FeatureStoreExecutionStateService/GetFeaturesetStateById',
                request_serializer=qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.GetFeaturesetStateByIdRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.GetFeaturesetStateByIdResponse.FromString,
                )
        self.GetFeaturesetStateByName = channel.unary_unary(
                '/qwak.feature.store.execution.v1.state.FeatureStoreExecutionStateService/GetFeaturesetStateByName',
                request_serializer=qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.GetFeaturesetStateByNameRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.GetFeaturesetStateByNameResponse.FromString,
                )
        self.GetMultiFeaturesetStateByIds = channel.unary_unary(
                '/qwak.feature.store.execution.v1.state.FeatureStoreExecutionStateService/GetMultiFeaturesetStateByIds',
                request_serializer=qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.GetMultiFeaturesetStateByIdsRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.GetMultiFeaturesetStateByIdsResponse.FromString,
                )
        self.GetMultiFeaturesetStateByName = channel.unary_unary(
                '/qwak.feature.store.execution.v1.state.FeatureStoreExecutionStateService/GetMultiFeaturesetStateByName',
                request_serializer=qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.GetMultiFeaturesetStateByNameRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.GetMultiFeaturesetStateByNameResponse.FromString,
                )
        self.UpdateMultiExecutionState = channel.unary_unary(
                '/qwak.feature.store.execution.v1.state.FeatureStoreExecutionStateService/UpdateMultiExecutionState',
                request_serializer=qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.UpdateMultiExecutionStateRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.UpdateMultiExecutionStateResponse.FromString,
                )
        self.DeleteFeaturesetStateById = channel.unary_unary(
                '/qwak.feature.store.execution.v1.state.FeatureStoreExecutionStateService/DeleteFeaturesetStateById',
                request_serializer=qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.DeleteFeaturesetStateByIdRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.DeleteFeaturesetStateByIdResponse.FromString,
                )


class FeatureStoreExecutionStateServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetFeaturesetStateById(self, request, context):
        """Get feature set state by feature set id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeaturesetStateByName(self, request, context):
        """Get feature set state by feature set name
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMultiFeaturesetStateByIds(self, request, context):
        """Get state of multiple feature sets by a list of IDs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMultiFeaturesetStateByName(self, request, context):
        """Get state of multiple feature sets by a list of names
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateMultiExecutionState(self, request, context):
        """Update state multiple executions - called by the edge state publisher
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFeaturesetStateById(self, request, context):
        """Delete feature set state
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FeatureStoreExecutionStateServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetFeaturesetStateById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeaturesetStateById,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.GetFeaturesetStateByIdRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.GetFeaturesetStateByIdResponse.SerializeToString,
            ),
            'GetFeaturesetStateByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeaturesetStateByName,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.GetFeaturesetStateByNameRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.GetFeaturesetStateByNameResponse.SerializeToString,
            ),
            'GetMultiFeaturesetStateByIds': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMultiFeaturesetStateByIds,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.GetMultiFeaturesetStateByIdsRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.GetMultiFeaturesetStateByIdsResponse.SerializeToString,
            ),
            'GetMultiFeaturesetStateByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMultiFeaturesetStateByName,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.GetMultiFeaturesetStateByNameRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.GetMultiFeaturesetStateByNameResponse.SerializeToString,
            ),
            'UpdateMultiExecutionState': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateMultiExecutionState,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.UpdateMultiExecutionStateRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.UpdateMultiExecutionStateResponse.SerializeToString,
            ),
            'DeleteFeaturesetStateById': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFeaturesetStateById,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.DeleteFeaturesetStateByIdRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.DeleteFeaturesetStateByIdResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.feature.store.execution.v1.state.FeatureStoreExecutionStateService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FeatureStoreExecutionStateService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetFeaturesetStateById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.state.FeatureStoreExecutionStateService/GetFeaturesetStateById',
            qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.GetFeaturesetStateByIdRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.GetFeaturesetStateByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeaturesetStateByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.state.FeatureStoreExecutionStateService/GetFeaturesetStateByName',
            qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.GetFeaturesetStateByNameRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.GetFeaturesetStateByNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMultiFeaturesetStateByIds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.state.FeatureStoreExecutionStateService/GetMultiFeaturesetStateByIds',
            qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.GetMultiFeaturesetStateByIdsRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.GetMultiFeaturesetStateByIdsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMultiFeaturesetStateByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.state.FeatureStoreExecutionStateService/GetMultiFeaturesetStateByName',
            qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.GetMultiFeaturesetStateByNameRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.GetMultiFeaturesetStateByNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateMultiExecutionState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.state.FeatureStoreExecutionStateService/UpdateMultiExecutionState',
            qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.UpdateMultiExecutionStateRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.UpdateMultiExecutionStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteFeaturesetStateById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.state.FeatureStoreExecutionStateService/DeleteFeaturesetStateById',
            qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.DeleteFeaturesetStateByIdRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_state_dot_execution__state__service__pb2.DeleteFeaturesetStateByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
