# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/features/feature_set_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.feature_store.features import feature_set_state_pb2 as qwak_dot_feature__store_dot_features_dot_feature__set__state__pb2
from _qwak_proto.qwak.feature_store.features import feature_set_pb2 as qwak_dot_feature__store_dot_features_dot_feature__set__pb2
from _qwak_proto.qwak.feature_store.features import feature_set_types_pb2 as qwak_dot_feature__store_dot_features_dot_feature__set__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5qwak/feature_store/features/feature_set_service.proto\x12\x1bqwak.feature.store.features\x1a\x33qwak/feature_store/features/feature_set_state.proto\x1a-qwak/feature_store/features/feature_set.proto\x1a\x33qwak/feature_store/features/feature_set_types.proto\"b\n\x19RegisterFeatureSetRequest\x12\x45\n\x10\x66\x65\x61ture_set_spec\x18\x01 \x01(\x0b\x32+.qwak.feature.store.features.FeatureSetSpec\"Z\n\x1aRegisterFeatureSetResponse\x12<\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32\'.qwak.feature.store.features.FeatureSet\"x\n\x17UpdateFeatureSetRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x45\n\x10\x66\x65\x61ture_set_spec\x18\x02 \x01(\x0b\x32+.qwak.feature.store.features.FeatureSetSpec\"X\n\x18UpdateFeatureSetResponse\x12<\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32\'.qwak.feature.store.features.FeatureSet\"2\n\x18GetFeatureSetByIdRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\"Y\n\x19GetFeatureSetByIdResponse\x12<\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32\'.qwak.feature.store.features.FeatureSet\"6\n\x1aGetFeatureSetByNameRequest\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x01 \x01(\t\"[\n\x1bGetFeatureSetByNameResponse\x12<\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32\'.qwak.feature.store.features.FeatureSet\"1\n\x17\x44\x65leteFeatureSetRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\"\x1a\n\x18\x44\x65leteFeatureSetResponse\"\x18\n\x16ListFeatureSetsRequest\"\\\n\x17ListFeatureSetsResponse\x12\x41\n\x10\x66\x65\x61ture_families\x18\x01 \x03(\x0b\x32\'.qwak.feature.store.features.FeatureSet\"5\n\x19RunBatchFeatureSetRequest\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x01 \x01(\t\"\x1c\n\x1aRunBatchFeatureSetResponse\"p\n RunParquetBatchFeatureSetRequest\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x01 \x01(\t\x12\x18\n\x10parquet_location\x18\x02 \x01(\t\x12\x18\n\x10timestamp_column\x18\x03 \x01(\t\"#\n!RunParquetBatchFeatureSetResponse\"2\n\x16\x43reateUploadURLRequest\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x01 \x01(\t\"x\n\x18\x43reateUploadURLRequestV1\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x01 \x01(\t\x12\x43\n\x0etransformation\x18\x02 \x01(\x0b\x32+.qwak.feature.store.features.Transformation\"I\n.CreateRealTimeFeatureExtractorUploadURLRequest\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x01 \x01(\t\"-\n\x17\x43reateUploadURLResponse\x12\x12\n\nupload_url\x18\x01 \x01(\t\"\x89\x02\n\x1cUpdateFeatureSetStateRequest\x12m\n\x13\x66\x65\x61ture_names_state\x18\x01 \x03(\x0b\x32P.qwak.feature.store.features.UpdateFeatureSetStateRequest.FeatureNamesStateEntry\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\x1a\x62\n\x16\x46\x65\x61tureNamesStateEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x37\n\x05value\x18\x02 \x01(\x0b\x32(.qwak.feature.store.features.StateUpdate:\x02\x38\x01\"e\n\x0bStateUpdate\x12V\n\x13\x66\x65\x61ture_names_state\x18\x01 \x01(\x0e\x32\x39.qwak.feature.store.features.FeatureSetLastExecutionState\"\x1f\n\x1dUpdateFeatureSetStateResponse\"K\n\x1fGetFeatureSetStateByNameRequest\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x01 \x01(\t\x12\x0e\n\x06run_id\x18\x02 \x01(\x03\"x\n GetFeatureSetStateByNameResponse\x12T\n\x11\x66\x65\x61ture_set_state\x18\x01 \x01(\x0e\x32\x39.qwak.feature.store.features.FeatureSetLastExecutionState\"9\n\x1dGetFeatureSetStateByIdRequest\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x01 \x01(\t\"^\n\x1eGetFeatureSetStateByIdResponse\x12<\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32\'.qwak.feature.store.features.FeatureSet\"1\n\x16PauseFeaturesetRequest\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x01 \x01(\t\"\x19\n\x17PauseFeaturesetResponse\"2\n\x17ResumeFeaturesetRequest\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x01 \x01(\t\"\x1a\n\x18ResumeFeaturesetResponse\">\n#GetFeaturesetSchedulingStateRequest\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x01 \x01(\t\"m\n$GetFeaturesetSchedulingStateResponse\x12\x45\n\x05state\x18\x01 \x01(\x0e\x32\x36.qwak.feature.store.features.FeaturesetSchedulingState2\xe4\x12\n\x11\x46\x65\x61tureSetService\x12\x85\x01\n\x12RegisterFeatureSet\x12\x36.qwak.feature.store.features.RegisterFeatureSetRequest\x1a\x37.qwak.feature.store.features.RegisterFeatureSetResponse\x12\x7f\n\x10UpdateFeatureSet\x12\x34.qwak.feature.store.features.UpdateFeatureSetRequest\x1a\x35.qwak.feature.store.features.UpdateFeatureSetResponse\x12\x82\x01\n\x11GetFeatureSetById\x12\x35.qwak.feature.store.features.GetFeatureSetByIdRequest\x1a\x36.qwak.feature.store.features.GetFeatureSetByIdResponse\x12\x88\x01\n\x13GetFeatureSetByName\x12\x37.qwak.feature.store.features.GetFeatureSetByNameRequest\x1a\x38.qwak.feature.store.features.GetFeatureSetByNameResponse\x12\x7f\n\x10\x44\x65leteFeatureSet\x12\x34.qwak.feature.store.features.DeleteFeatureSetRequest\x1a\x35.qwak.feature.store.features.DeleteFeatureSetResponse\x12|\n\x0fListFeatureSets\x12\x33.qwak.feature.store.features.ListFeatureSetsRequest\x1a\x34.qwak.feature.store.features.ListFeatureSetsResponse\x12\x85\x01\n\x12RunBatchFeatureSet\x12\x36.qwak.feature.store.features.RunBatchFeatureSetRequest\x1a\x37.qwak.feature.store.features.RunBatchFeatureSetResponse\x12\x9a\x01\n\x19RunParquetBatchFeatureSet\x12=.qwak.feature.store.features.RunParquetBatchFeatureSetRequest\x1a>.qwak.feature.store.features.RunParquetBatchFeatureSetResponse\x12|\n\x0f\x43reateUploadURL\x12\x33.qwak.feature.store.features.CreateUploadURLRequest\x1a\x34.qwak.feature.store.features.CreateUploadURLResponse\x12\x80\x01\n\x11\x43reateUploadURLV1\x12\x35.qwak.feature.store.features.CreateUploadURLRequestV1\x1a\x34.qwak.feature.store.features.CreateUploadURLResponse\x12\xac\x01\n\'CreateRealTimeFeatureExtractorUploadURL\x12K.qwak.feature.store.features.CreateRealTimeFeatureExtractorUploadURLRequest\x1a\x34.qwak.feature.store.features.CreateUploadURLResponse\x12\x8e\x01\n\x15UpdateFeatureSetState\x12\x39.qwak.feature.store.features.UpdateFeatureSetStateRequest\x1a:.qwak.feature.store.features.UpdateFeatureSetStateResponse\x12\x97\x01\n\x18GetFeatureSetStateByName\x12<.qwak.feature.store.features.GetFeatureSetStateByNameRequest\x1a=.qwak.feature.store.features.GetFeatureSetStateByNameResponse\x12\x91\x01\n\x16GetFeatureSetStateById\x12:.qwak.feature.store.features.GetFeatureSetStateByIdRequest\x1a;.qwak.feature.store.features.GetFeatureSetStateByIdResponse\x12|\n\x0fPauseFeatureset\x12\x33.qwak.feature.store.features.PauseFeaturesetRequest\x1a\x34.qwak.feature.store.features.PauseFeaturesetResponse\x12\x7f\n\x10ResumeFeatureset\x12\x34.qwak.feature.store.features.ResumeFeaturesetRequest\x1a\x35.qwak.feature.store.features.ResumeFeaturesetResponse\x12\xa3\x01\n\x1cGetFeaturesetSchedulingState\x12@.qwak.feature.store.features.GetFeaturesetSchedulingStateRequest\x1a\x41.qwak.feature.store.features.GetFeaturesetSchedulingStateResponseB]\n(com.qwak.ai.feature.store.management.apiP\x01Z/qwak/featurestore/features;featurestorefeaturesb\x06proto3')



_REGISTERFEATURESETREQUEST = DESCRIPTOR.message_types_by_name['RegisterFeatureSetRequest']
_REGISTERFEATURESETRESPONSE = DESCRIPTOR.message_types_by_name['RegisterFeatureSetResponse']
_UPDATEFEATURESETREQUEST = DESCRIPTOR.message_types_by_name['UpdateFeatureSetRequest']
_UPDATEFEATURESETRESPONSE = DESCRIPTOR.message_types_by_name['UpdateFeatureSetResponse']
_GETFEATURESETBYIDREQUEST = DESCRIPTOR.message_types_by_name['GetFeatureSetByIdRequest']
_GETFEATURESETBYIDRESPONSE = DESCRIPTOR.message_types_by_name['GetFeatureSetByIdResponse']
_GETFEATURESETBYNAMEREQUEST = DESCRIPTOR.message_types_by_name['GetFeatureSetByNameRequest']
_GETFEATURESETBYNAMERESPONSE = DESCRIPTOR.message_types_by_name['GetFeatureSetByNameResponse']
_DELETEFEATURESETREQUEST = DESCRIPTOR.message_types_by_name['DeleteFeatureSetRequest']
_DELETEFEATURESETRESPONSE = DESCRIPTOR.message_types_by_name['DeleteFeatureSetResponse']
_LISTFEATURESETSREQUEST = DESCRIPTOR.message_types_by_name['ListFeatureSetsRequest']
_LISTFEATURESETSRESPONSE = DESCRIPTOR.message_types_by_name['ListFeatureSetsResponse']
_RUNBATCHFEATURESETREQUEST = DESCRIPTOR.message_types_by_name['RunBatchFeatureSetRequest']
_RUNBATCHFEATURESETRESPONSE = DESCRIPTOR.message_types_by_name['RunBatchFeatureSetResponse']
_RUNPARQUETBATCHFEATURESETREQUEST = DESCRIPTOR.message_types_by_name['RunParquetBatchFeatureSetRequest']
_RUNPARQUETBATCHFEATURESETRESPONSE = DESCRIPTOR.message_types_by_name['RunParquetBatchFeatureSetResponse']
_CREATEUPLOADURLREQUEST = DESCRIPTOR.message_types_by_name['CreateUploadURLRequest']
_CREATEUPLOADURLREQUESTV1 = DESCRIPTOR.message_types_by_name['CreateUploadURLRequestV1']
_CREATEREALTIMEFEATUREEXTRACTORUPLOADURLREQUEST = DESCRIPTOR.message_types_by_name['CreateRealTimeFeatureExtractorUploadURLRequest']
_CREATEUPLOADURLRESPONSE = DESCRIPTOR.message_types_by_name['CreateUploadURLResponse']
_UPDATEFEATURESETSTATEREQUEST = DESCRIPTOR.message_types_by_name['UpdateFeatureSetStateRequest']
_UPDATEFEATURESETSTATEREQUEST_FEATURENAMESSTATEENTRY = _UPDATEFEATURESETSTATEREQUEST.nested_types_by_name['FeatureNamesStateEntry']
_STATEUPDATE = DESCRIPTOR.message_types_by_name['StateUpdate']
_UPDATEFEATURESETSTATERESPONSE = DESCRIPTOR.message_types_by_name['UpdateFeatureSetStateResponse']
_GETFEATURESETSTATEBYNAMEREQUEST = DESCRIPTOR.message_types_by_name['GetFeatureSetStateByNameRequest']
_GETFEATURESETSTATEBYNAMERESPONSE = DESCRIPTOR.message_types_by_name['GetFeatureSetStateByNameResponse']
_GETFEATURESETSTATEBYIDREQUEST = DESCRIPTOR.message_types_by_name['GetFeatureSetStateByIdRequest']
_GETFEATURESETSTATEBYIDRESPONSE = DESCRIPTOR.message_types_by_name['GetFeatureSetStateByIdResponse']
_PAUSEFEATURESETREQUEST = DESCRIPTOR.message_types_by_name['PauseFeaturesetRequest']
_PAUSEFEATURESETRESPONSE = DESCRIPTOR.message_types_by_name['PauseFeaturesetResponse']
_RESUMEFEATURESETREQUEST = DESCRIPTOR.message_types_by_name['ResumeFeaturesetRequest']
_RESUMEFEATURESETRESPONSE = DESCRIPTOR.message_types_by_name['ResumeFeaturesetResponse']
_GETFEATURESETSCHEDULINGSTATEREQUEST = DESCRIPTOR.message_types_by_name['GetFeaturesetSchedulingStateRequest']
_GETFEATURESETSCHEDULINGSTATERESPONSE = DESCRIPTOR.message_types_by_name['GetFeaturesetSchedulingStateResponse']
RegisterFeatureSetRequest = _reflection.GeneratedProtocolMessageType('RegisterFeatureSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERFEATURESETREQUEST,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.RegisterFeatureSetRequest)
  })
_sym_db.RegisterMessage(RegisterFeatureSetRequest)

RegisterFeatureSetResponse = _reflection.GeneratedProtocolMessageType('RegisterFeatureSetResponse', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERFEATURESETRESPONSE,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.RegisterFeatureSetResponse)
  })
_sym_db.RegisterMessage(RegisterFeatureSetResponse)

UpdateFeatureSetRequest = _reflection.GeneratedProtocolMessageType('UpdateFeatureSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATURESETREQUEST,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.UpdateFeatureSetRequest)
  })
_sym_db.RegisterMessage(UpdateFeatureSetRequest)

UpdateFeatureSetResponse = _reflection.GeneratedProtocolMessageType('UpdateFeatureSetResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATURESETRESPONSE,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.UpdateFeatureSetResponse)
  })
_sym_db.RegisterMessage(UpdateFeatureSetResponse)

GetFeatureSetByIdRequest = _reflection.GeneratedProtocolMessageType('GetFeatureSetByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESETBYIDREQUEST,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.GetFeatureSetByIdRequest)
  })
_sym_db.RegisterMessage(GetFeatureSetByIdRequest)

GetFeatureSetByIdResponse = _reflection.GeneratedProtocolMessageType('GetFeatureSetByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESETBYIDRESPONSE,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.GetFeatureSetByIdResponse)
  })
_sym_db.RegisterMessage(GetFeatureSetByIdResponse)

GetFeatureSetByNameRequest = _reflection.GeneratedProtocolMessageType('GetFeatureSetByNameRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESETBYNAMEREQUEST,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.GetFeatureSetByNameRequest)
  })
_sym_db.RegisterMessage(GetFeatureSetByNameRequest)

GetFeatureSetByNameResponse = _reflection.GeneratedProtocolMessageType('GetFeatureSetByNameResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESETBYNAMERESPONSE,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.GetFeatureSetByNameResponse)
  })
_sym_db.RegisterMessage(GetFeatureSetByNameResponse)

DeleteFeatureSetRequest = _reflection.GeneratedProtocolMessageType('DeleteFeatureSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATURESETREQUEST,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.DeleteFeatureSetRequest)
  })
_sym_db.RegisterMessage(DeleteFeatureSetRequest)

DeleteFeatureSetResponse = _reflection.GeneratedProtocolMessageType('DeleteFeatureSetResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATURESETRESPONSE,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.DeleteFeatureSetResponse)
  })
_sym_db.RegisterMessage(DeleteFeatureSetResponse)

ListFeatureSetsRequest = _reflection.GeneratedProtocolMessageType('ListFeatureSetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESETSREQUEST,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.ListFeatureSetsRequest)
  })
_sym_db.RegisterMessage(ListFeatureSetsRequest)

ListFeatureSetsResponse = _reflection.GeneratedProtocolMessageType('ListFeatureSetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESETSRESPONSE,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.ListFeatureSetsResponse)
  })
_sym_db.RegisterMessage(ListFeatureSetsResponse)

RunBatchFeatureSetRequest = _reflection.GeneratedProtocolMessageType('RunBatchFeatureSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNBATCHFEATURESETREQUEST,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.RunBatchFeatureSetRequest)
  })
_sym_db.RegisterMessage(RunBatchFeatureSetRequest)

RunBatchFeatureSetResponse = _reflection.GeneratedProtocolMessageType('RunBatchFeatureSetResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNBATCHFEATURESETRESPONSE,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.RunBatchFeatureSetResponse)
  })
_sym_db.RegisterMessage(RunBatchFeatureSetResponse)

RunParquetBatchFeatureSetRequest = _reflection.GeneratedProtocolMessageType('RunParquetBatchFeatureSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNPARQUETBATCHFEATURESETREQUEST,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.RunParquetBatchFeatureSetRequest)
  })
_sym_db.RegisterMessage(RunParquetBatchFeatureSetRequest)

RunParquetBatchFeatureSetResponse = _reflection.GeneratedProtocolMessageType('RunParquetBatchFeatureSetResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNPARQUETBATCHFEATURESETRESPONSE,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.RunParquetBatchFeatureSetResponse)
  })
_sym_db.RegisterMessage(RunParquetBatchFeatureSetResponse)

CreateUploadURLRequest = _reflection.GeneratedProtocolMessageType('CreateUploadURLRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUPLOADURLREQUEST,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.CreateUploadURLRequest)
  })
_sym_db.RegisterMessage(CreateUploadURLRequest)

CreateUploadURLRequestV1 = _reflection.GeneratedProtocolMessageType('CreateUploadURLRequestV1', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUPLOADURLREQUESTV1,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.CreateUploadURLRequestV1)
  })
_sym_db.RegisterMessage(CreateUploadURLRequestV1)

CreateRealTimeFeatureExtractorUploadURLRequest = _reflection.GeneratedProtocolMessageType('CreateRealTimeFeatureExtractorUploadURLRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEREALTIMEFEATUREEXTRACTORUPLOADURLREQUEST,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.CreateRealTimeFeatureExtractorUploadURLRequest)
  })
_sym_db.RegisterMessage(CreateRealTimeFeatureExtractorUploadURLRequest)

CreateUploadURLResponse = _reflection.GeneratedProtocolMessageType('CreateUploadURLResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUPLOADURLRESPONSE,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.CreateUploadURLResponse)
  })
_sym_db.RegisterMessage(CreateUploadURLResponse)

UpdateFeatureSetStateRequest = _reflection.GeneratedProtocolMessageType('UpdateFeatureSetStateRequest', (_message.Message,), {

  'FeatureNamesStateEntry' : _reflection.GeneratedProtocolMessageType('FeatureNamesStateEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEFEATURESETSTATEREQUEST_FEATURENAMESSTATEENTRY,
    '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
    # @@protoc_insertion_point(class_scope:qwak.feature.store.features.UpdateFeatureSetStateRequest.FeatureNamesStateEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEFEATURESETSTATEREQUEST,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.UpdateFeatureSetStateRequest)
  })
_sym_db.RegisterMessage(UpdateFeatureSetStateRequest)
_sym_db.RegisterMessage(UpdateFeatureSetStateRequest.FeatureNamesStateEntry)

StateUpdate = _reflection.GeneratedProtocolMessageType('StateUpdate', (_message.Message,), {
  'DESCRIPTOR' : _STATEUPDATE,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.StateUpdate)
  })
_sym_db.RegisterMessage(StateUpdate)

UpdateFeatureSetStateResponse = _reflection.GeneratedProtocolMessageType('UpdateFeatureSetStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATURESETSTATERESPONSE,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.UpdateFeatureSetStateResponse)
  })
_sym_db.RegisterMessage(UpdateFeatureSetStateResponse)

GetFeatureSetStateByNameRequest = _reflection.GeneratedProtocolMessageType('GetFeatureSetStateByNameRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESETSTATEBYNAMEREQUEST,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.GetFeatureSetStateByNameRequest)
  })
_sym_db.RegisterMessage(GetFeatureSetStateByNameRequest)

GetFeatureSetStateByNameResponse = _reflection.GeneratedProtocolMessageType('GetFeatureSetStateByNameResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESETSTATEBYNAMERESPONSE,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.GetFeatureSetStateByNameResponse)
  })
_sym_db.RegisterMessage(GetFeatureSetStateByNameResponse)

GetFeatureSetStateByIdRequest = _reflection.GeneratedProtocolMessageType('GetFeatureSetStateByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESETSTATEBYIDREQUEST,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.GetFeatureSetStateByIdRequest)
  })
_sym_db.RegisterMessage(GetFeatureSetStateByIdRequest)

GetFeatureSetStateByIdResponse = _reflection.GeneratedProtocolMessageType('GetFeatureSetStateByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESETSTATEBYIDRESPONSE,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.GetFeatureSetStateByIdResponse)
  })
_sym_db.RegisterMessage(GetFeatureSetStateByIdResponse)

PauseFeaturesetRequest = _reflection.GeneratedProtocolMessageType('PauseFeaturesetRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEFEATURESETREQUEST,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.PauseFeaturesetRequest)
  })
_sym_db.RegisterMessage(PauseFeaturesetRequest)

PauseFeaturesetResponse = _reflection.GeneratedProtocolMessageType('PauseFeaturesetResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEFEATURESETRESPONSE,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.PauseFeaturesetResponse)
  })
_sym_db.RegisterMessage(PauseFeaturesetResponse)

ResumeFeaturesetRequest = _reflection.GeneratedProtocolMessageType('ResumeFeaturesetRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEFEATURESETREQUEST,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.ResumeFeaturesetRequest)
  })
_sym_db.RegisterMessage(ResumeFeaturesetRequest)

ResumeFeaturesetResponse = _reflection.GeneratedProtocolMessageType('ResumeFeaturesetResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEFEATURESETRESPONSE,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.ResumeFeaturesetResponse)
  })
_sym_db.RegisterMessage(ResumeFeaturesetResponse)

GetFeaturesetSchedulingStateRequest = _reflection.GeneratedProtocolMessageType('GetFeaturesetSchedulingStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESETSCHEDULINGSTATEREQUEST,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.GetFeaturesetSchedulingStateRequest)
  })
_sym_db.RegisterMessage(GetFeaturesetSchedulingStateRequest)

GetFeaturesetSchedulingStateResponse = _reflection.GeneratedProtocolMessageType('GetFeaturesetSchedulingStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESETSCHEDULINGSTATERESPONSE,
  '__module__' : 'qwak.feature_store.features.feature_set_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.GetFeaturesetSchedulingStateResponse)
  })
_sym_db.RegisterMessage(GetFeaturesetSchedulingStateResponse)

_FEATURESETSERVICE = DESCRIPTOR.services_by_name['FeatureSetService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(com.qwak.ai.feature.store.management.apiP\001Z/qwak/featurestore/features;featurestorefeatures'
  _UPDATEFEATURESETSTATEREQUEST_FEATURENAMESSTATEENTRY._options = None
  _UPDATEFEATURESETSTATEREQUEST_FEATURENAMESSTATEENTRY._serialized_options = b'8\001'
  _REGISTERFEATURESETREQUEST._serialized_start=239
  _REGISTERFEATURESETREQUEST._serialized_end=337
  _REGISTERFEATURESETRESPONSE._serialized_start=339
  _REGISTERFEATURESETRESPONSE._serialized_end=429
  _UPDATEFEATURESETREQUEST._serialized_start=431
  _UPDATEFEATURESETREQUEST._serialized_end=551
  _UPDATEFEATURESETRESPONSE._serialized_start=553
  _UPDATEFEATURESETRESPONSE._serialized_end=641
  _GETFEATURESETBYIDREQUEST._serialized_start=643
  _GETFEATURESETBYIDREQUEST._serialized_end=693
  _GETFEATURESETBYIDRESPONSE._serialized_start=695
  _GETFEATURESETBYIDRESPONSE._serialized_end=784
  _GETFEATURESETBYNAMEREQUEST._serialized_start=786
  _GETFEATURESETBYNAMEREQUEST._serialized_end=840
  _GETFEATURESETBYNAMERESPONSE._serialized_start=842
  _GETFEATURESETBYNAMERESPONSE._serialized_end=933
  _DELETEFEATURESETREQUEST._serialized_start=935
  _DELETEFEATURESETREQUEST._serialized_end=984
  _DELETEFEATURESETRESPONSE._serialized_start=986
  _DELETEFEATURESETRESPONSE._serialized_end=1012
  _LISTFEATURESETSREQUEST._serialized_start=1014
  _LISTFEATURESETSREQUEST._serialized_end=1038
  _LISTFEATURESETSRESPONSE._serialized_start=1040
  _LISTFEATURESETSRESPONSE._serialized_end=1132
  _RUNBATCHFEATURESETREQUEST._serialized_start=1134
  _RUNBATCHFEATURESETREQUEST._serialized_end=1187
  _RUNBATCHFEATURESETRESPONSE._serialized_start=1189
  _RUNBATCHFEATURESETRESPONSE._serialized_end=1217
  _RUNPARQUETBATCHFEATURESETREQUEST._serialized_start=1219
  _RUNPARQUETBATCHFEATURESETREQUEST._serialized_end=1331
  _RUNPARQUETBATCHFEATURESETRESPONSE._serialized_start=1333
  _RUNPARQUETBATCHFEATURESETRESPONSE._serialized_end=1368
  _CREATEUPLOADURLREQUEST._serialized_start=1370
  _CREATEUPLOADURLREQUEST._serialized_end=1420
  _CREATEUPLOADURLREQUESTV1._serialized_start=1422
  _CREATEUPLOADURLREQUESTV1._serialized_end=1542
  _CREATEREALTIMEFEATUREEXTRACTORUPLOADURLREQUEST._serialized_start=1544
  _CREATEREALTIMEFEATUREEXTRACTORUPLOADURLREQUEST._serialized_end=1617
  _CREATEUPLOADURLRESPONSE._serialized_start=1619
  _CREATEUPLOADURLRESPONSE._serialized_end=1664
  _UPDATEFEATURESETSTATEREQUEST._serialized_start=1667
  _UPDATEFEATURESETSTATEREQUEST._serialized_end=1932
  _UPDATEFEATURESETSTATEREQUEST_FEATURENAMESSTATEENTRY._serialized_start=1834
  _UPDATEFEATURESETSTATEREQUEST_FEATURENAMESSTATEENTRY._serialized_end=1932
  _STATEUPDATE._serialized_start=1934
  _STATEUPDATE._serialized_end=2035
  _UPDATEFEATURESETSTATERESPONSE._serialized_start=2037
  _UPDATEFEATURESETSTATERESPONSE._serialized_end=2068
  _GETFEATURESETSTATEBYNAMEREQUEST._serialized_start=2070
  _GETFEATURESETSTATEBYNAMEREQUEST._serialized_end=2145
  _GETFEATURESETSTATEBYNAMERESPONSE._serialized_start=2147
  _GETFEATURESETSTATEBYNAMERESPONSE._serialized_end=2267
  _GETFEATURESETSTATEBYIDREQUEST._serialized_start=2269
  _GETFEATURESETSTATEBYIDREQUEST._serialized_end=2326
  _GETFEATURESETSTATEBYIDRESPONSE._serialized_start=2328
  _GETFEATURESETSTATEBYIDRESPONSE._serialized_end=2422
  _PAUSEFEATURESETREQUEST._serialized_start=2424
  _PAUSEFEATURESETREQUEST._serialized_end=2473
  _PAUSEFEATURESETRESPONSE._serialized_start=2475
  _PAUSEFEATURESETRESPONSE._serialized_end=2500
  _RESUMEFEATURESETREQUEST._serialized_start=2502
  _RESUMEFEATURESETREQUEST._serialized_end=2552
  _RESUMEFEATURESETRESPONSE._serialized_start=2554
  _RESUMEFEATURESETRESPONSE._serialized_end=2580
  _GETFEATURESETSCHEDULINGSTATEREQUEST._serialized_start=2582
  _GETFEATURESETSCHEDULINGSTATEREQUEST._serialized_end=2644
  _GETFEATURESETSCHEDULINGSTATERESPONSE._serialized_start=2646
  _GETFEATURESETSCHEDULINGSTATERESPONSE._serialized_end=2755
  _FEATURESETSERVICE._serialized_start=2758
  _FEATURESETSERVICE._serialized_end=5162
# @@protoc_insertion_point(module_scope)
