# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/features/deployment_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.feature_store.features import deployment_pb2 as qwak_dot_feature__store_dot_features_dot_deployment__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4qwak/feature_store/features/deployment_service.proto\x12\x1bqwak.feature.store.features\x1a,qwak/feature_store/features/deployment.proto\"\x87\x01\n%PushEnvironmentDeploymentStateRequest\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\x12\x46\n\x10\x64\x65ployment_state\x18\x02 \x03(\x0b\x32,.qwak.feature.store.features.DeploymentState\"(\n&PushEnvironmentDeploymentStateResponse2\xc9\x01\n\x1b\x44\x65ploymentManagementService\x12\xa9\x01\n\x1ePushEnvironmentDeploymentState\x12\x42.qwak.feature.store.features.PushEnvironmentDeploymentStateRequest\x1a\x43.qwak.feature.store.features.PushEnvironmentDeploymentStateResponseB]\n(com.qwak.ai.feature.store.management.apiP\x01Z/qwak/featurestore/features;featurestorefeaturesb\x06proto3')



_PUSHENVIRONMENTDEPLOYMENTSTATEREQUEST = DESCRIPTOR.message_types_by_name['PushEnvironmentDeploymentStateRequest']
_PUSHENVIRONMENTDEPLOYMENTSTATERESPONSE = DESCRIPTOR.message_types_by_name['PushEnvironmentDeploymentStateResponse']
PushEnvironmentDeploymentStateRequest = _reflection.GeneratedProtocolMessageType('PushEnvironmentDeploymentStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUSHENVIRONMENTDEPLOYMENTSTATEREQUEST,
  '__module__' : 'qwak.feature_store.features.deployment_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.PushEnvironmentDeploymentStateRequest)
  })
_sym_db.RegisterMessage(PushEnvironmentDeploymentStateRequest)

PushEnvironmentDeploymentStateResponse = _reflection.GeneratedProtocolMessageType('PushEnvironmentDeploymentStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _PUSHENVIRONMENTDEPLOYMENTSTATERESPONSE,
  '__module__' : 'qwak.feature_store.features.deployment_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.features.PushEnvironmentDeploymentStateResponse)
  })
_sym_db.RegisterMessage(PushEnvironmentDeploymentStateResponse)

_DEPLOYMENTMANAGEMENTSERVICE = DESCRIPTOR.services_by_name['DeploymentManagementService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(com.qwak.ai.feature.store.management.apiP\001Z/qwak/featurestore/features;featurestorefeatures'
  _PUSHENVIRONMENTDEPLOYMENTSTATEREQUEST._serialized_start=132
  _PUSHENVIRONMENTDEPLOYMENTSTATEREQUEST._serialized_end=267
  _PUSHENVIRONMENTDEPLOYMENTSTATERESPONSE._serialized_start=269
  _PUSHENVIRONMENTDEPLOYMENTSTATERESPONSE._serialized_end=309
  _DEPLOYMENTMANAGEMENTSERVICE._serialized_start=312
  _DEPLOYMENTMANAGEMENTSERVICE._serialized_end=513
# @@protoc_insertion_point(module_scope)
